@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: QuickCheck
-version: 2.4.1.1
-id: QuickCheck-2.4.1.1-6b2df10756c9ae534bddffc57c532df8
+version: 2.5.1.1
+id: QuickCheck-2.5.1.1-4a9242f1b61a140fe486a54f5467ba42
 
 license: BSD3
-copyright: 2000-2011 Koen Claessen, 2006-2008 Björn Bringert, 2009-2011 Nick Smallbone
+copyright: 2000-2012 Koen Claessen, 2006-2008 Björn Bringert, 2009-2012 Nick Smallbone
 maintainer: QuickCheck developers <quickcheck@projects.haskell.org>
 stability:
 homepage: http://code.haskell.org/QuickCheck
 package-url:
+synopsis: Automatic testing of Haskell programs
 description: QuickCheck is a library for random testing of program properties.
              .
              The programmer provides a specification of the program, in
@@ -31,22 +32,22 @@ exposed-modules: Test.QuickCheck.All Test.QuickCheck.Function
                  Test.QuickCheck.Property Test.QuickCheck.Test Test.QuickCheck.Text
                  Test.QuickCheck.Poly Test.QuickCheck.State
 hidden-modules: Test.QuickCheck.Exception
-import-dirs: /usr/local/lib/ghc/QuickCheck-2.4.1.1
-library-dirs: /usr/local/lib/ghc/QuickCheck-2.4.1.1
-hs-libraries: HSQuickCheck-2.4.1.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/QuickCheck-2.5.1.1
+library-dirs: /usr/local/lib/ghc/QuickCheck-2.5.1.1
+hs-libraries: HSQuickCheck-2.5.1.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         random-1.0.0.3-7511feaba03eecc22356464da8976c7e
-         template-haskell-2.5.0.0-b8491f77d06d290bb99ada53d74aa786
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
+         template-haskell-2.7.0.0-826c08e99d445bf7fa4a34d70f491207
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-QuickCheck-2.4.1.1/html/QuickCheck.haddock
-haddock-html: /usr/local/share/doc/hs-QuickCheck-2.4.1.1/html
+haddock-interfaces: /usr/local/share/doc/hs-QuickCheck-2.5.1.1/html/QuickCheck.haddock
+haddock-html: /usr/local/share/doc/hs-QuickCheck-2.5.1.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
